@@ -5,17 +5,7 @@ from __future__ import annotations
 
 import time
 from abc import ABCMeta, abstractmethod
-from typing import (
-    TYPE_CHECKING,
-    Callable,
-    Dict,
-    Hashable,
-    Iterable,
-    List,
-    NamedTuple,
-    Optional,
-    Union,
-)
+from typing import TYPE_CHECKING, Callable, Hashable, Iterable, NamedTuple
 
 from prompt_toolkit.application.current import get_app
 from prompt_toolkit.buffer import Buffer
@@ -487,9 +477,7 @@ class DummyControl(UIControl):
         def get_line(i: int) -> StyleAndTextTuples:
             return []
 
-        return UIContent(
-            get_line=get_line, line_count=100**100
-        )  # Something very big.
+        return UIContent(get_line=get_line, line_count=100**100)  # Something very big.
 
     def is_focusable(self) -> bool:
         return False
